@@ -411,7 +411,7 @@ def create_serving_model(file_name,s3Path,servingproject,servingprojectid,pipPac
 		"type": model_type,
 		"training": training,
 		"userreqs": pipPackages,
-		"pipPackage": pipPackages,
+		"pipPackages": pipPackages,
 		"preprocessEnabled": preprocessEnabled,
 		"postprocessEnabled":postprocessEnabled,
 		"preprocessCodePath":preprocessS3Path,
